@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from .api.clusters_api import ClustersApi
+#   from .api.accounts_api import AccountsApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,27 +14,24 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
+from swx_sdk.api.accounts_api import AccountsApi
+from swx_sdk.api.apps_api import AppsApi
 from swx_sdk.api.clusters_api import ClustersApi
 from swx_sdk.api.data_api import DataApi
+from swx_sdk.api.invitations_api import InvitationsApi
 from swx_sdk.api.label_api import LabelApi
 from swx_sdk.api.labeled_entities_api import LabeledEntitiesApi
 from swx_sdk.api.mqtt_api import MQTTApi
+from swx_sdk.api.o_auth2_api import OAuth2Api
+from swx_sdk.api.open_id_api import OpenIDApi
+from swx_sdk.api.users_api import UsersApi
 from swx_sdk.api.actions_api import ActionsApi
-from swx_sdk.api.authentication_api import AuthenticationApi
-from swx_sdk.api.clients_api import ClientsApi
+from swx_sdk.api.build_configs_api import BuildConfigsApi
 from swx_sdk.api.collections_api import CollectionsApi
-from swx_sdk.api.discovery_api import DiscoveryApi
 from swx_sdk.api.events_api import EventsApi
-from swx_sdk.api.health_api import HealthApi
-from swx_sdk.api.labels_api import LabelsApi
-from swx_sdk.api.logging_api import LoggingApi
-from swx_sdk.api.mappings_api import MappingsApi
-from swx_sdk.api.message_templates_api import MessageTemplatesApi
 from swx_sdk.api.model_versions_api import ModelVersionsApi
 from swx_sdk.api.models_api import ModelsApi
 from swx_sdk.api.properties_api import PropertiesApi
-from swx_sdk.api.publishers_api import PublishersApi
-from swx_sdk.api.smartworks_api import SmartworksApi
-from swx_sdk.api.subscribers_api import SubscribersApi
+from swx_sdk.api.resources_api import ResourcesApi
 from swx_sdk.api.things_api import ThingsApi
 from swx_sdk.api.things_status_api import ThingsStatusApi
